@@ -33,9 +33,10 @@
 #  define KWIDGETSADDONS_DEPRECATED_NO_EXPORT KWIDGETSADDONS_NO_EXPORT KWIDGETSADDONS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KWIDGETSADDONS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KWIDGETSADDONS_NO_DEPRECATED
+#    define KWIDGETSADDONS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
